{ "type": "FoodNutrient", "id": 22687262, "nutrient": { "id": 1004, "number": "204", "name": "Total lipid (fat)", "nutrientUnit": { "name": "g", "conversionToMicroGram": 1000000, "aliases": [ "% (w/w)", "%" ] }, "rank": 800, "isNutrientLabel": false, "indentLevel": 1, "shortestName": "Total lipid (fat)" }, "value": 50, "foodNutrientDerivation": { "code": "LCCS", "description": "Calculated from value per serving size measure", "foodNutrientSource": { "id": 9, "code": "12", "description": "Manufacturer's analytical; partial documentation" } }, "percentDailyValue": 22 } { "type": "FoodNutrient", "id": 22687275, "nutrient": { "id": 1258, "number": "606", "name": "Fatty acids, total saturated", "nutrientUnit": { "name": "g", "conversionToMicroGram": 1000000, "aliases": [ "% (w/w)", "%" ] }, "rank": 9700, "isNutrientLabel": false, "indentLevel": 1, "shortestName": "Fatty acids, total saturated" }, "value": 3.57, "foodNutrientDerivation": { "code": "LCCS", "description": "Calculated from value per serving size measure", "foodNutrientSource": { "id": 9, "code": "12", "description": "Manufacturer's analytical; partial documentation" } }, "percentDailyValue": 5 }